import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class SQLAdminResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class BackupRunsResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, project: str, instance: str, id: str, **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def get(
            self, *, project: str, instance: str, id: str, **kwargs: typing.Any
        ) -> BackupRunHttpRequest: ...
        def insert(
            self,
            *,
            project: str,
            instance: str,
            body: BackupRun = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def list(
            self,
            *,
            project: str,
            instance: str,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> BackupRunsListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: BackupRunsListResponseHttpRequest,
            previous_response: BackupRunsListResponse,
        ) -> BackupRunsListResponseHttpRequest | None: ...

    @typing.type_check_only
    class ConnectResource(googleapiclient.discovery.Resource):
        def generateEphemeralCert(
            self,
            *,
            project: str,
            instance: str,
            body: GenerateEphemeralCertRequest = ...,
            **kwargs: typing.Any
        ) -> GenerateEphemeralCertResponseHttpRequest: ...
        def get(
            self,
            *,
            project: str,
            instance: str,
            readTime: str = ...,
            **kwargs: typing.Any
        ) -> ConnectSettingsHttpRequest: ...

    @typing.type_check_only
    class DatabasesResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, project: str, instance: str, database: str, **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def get(
            self, *, project: str, instance: str, database: str, **kwargs: typing.Any
        ) -> DatabaseHttpRequest: ...
        def insert(
            self,
            *,
            project: str,
            instance: str,
            body: Database = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def list(
            self, *, project: str, instance: str, **kwargs: typing.Any
        ) -> DatabasesListResponseHttpRequest: ...
        def patch(
            self,
            *,
            project: str,
            instance: str,
            database: str,
            body: Database = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def update(
            self,
            *,
            project: str,
            instance: str,
            database: str,
            body: Database = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...

    @typing.type_check_only
    class FlagsResource(googleapiclient.discovery.Resource):
        def list(
            self, *, databaseVersion: str = ..., **kwargs: typing.Any
        ) -> FlagsListResponseHttpRequest: ...

    @typing.type_check_only
    class InstancesResource(googleapiclient.discovery.Resource):
        def addServerCa(
            self, *, project: str, instance: str, **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def clone(
            self,
            *,
            project: str,
            instance: str,
            body: InstancesCloneRequest = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def delete(
            self, *, project: str, instance: str, **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def demoteMaster(
            self,
            *,
            project: str,
            instance: str,
            body: InstancesDemoteMasterRequest = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def export(
            self,
            *,
            project: str,
            instance: str,
            body: InstancesExportRequest = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def failover(
            self,
            *,
            project: str,
            instance: str,
            body: InstancesFailoverRequest = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def get(
            self, *, project: str, instance: str, **kwargs: typing.Any
        ) -> DatabaseInstanceHttpRequest: ...
        def import_(
            self,
            *,
            project: str,
            instance: str,
            body: InstancesImportRequest = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def insert(
            self, *, project: str, body: DatabaseInstance = ..., **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def list(
            self,
            *,
            project: str,
            filter: str = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> InstancesListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: InstancesListResponseHttpRequest,
            previous_response: InstancesListResponse,
        ) -> InstancesListResponseHttpRequest | None: ...
        def listServerCas(
            self, *, project: str, instance: str, **kwargs: typing.Any
        ) -> InstancesListServerCasResponseHttpRequest: ...
        def patch(
            self,
            *,
            project: str,
            instance: str,
            body: DatabaseInstance = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def promoteReplica(
            self, *, project: str, instance: str, **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def resetSslConfig(
            self, *, project: str, instance: str, **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def restart(
            self, *, project: str, instance: str, **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def restoreBackup(
            self,
            *,
            project: str,
            instance: str,
            body: InstancesRestoreBackupRequest = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def rotateServerCa(
            self,
            *,
            project: str,
            instance: str,
            body: InstancesRotateServerCaRequest = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def startReplica(
            self, *, project: str, instance: str, **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def stopReplica(
            self, *, project: str, instance: str, **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def truncateLog(
            self,
            *,
            project: str,
            instance: str,
            body: InstancesTruncateLogRequest = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def update(
            self,
            *,
            project: str,
            instance: str,
            body: DatabaseInstance = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...

    @typing.type_check_only
    class OperationsResource(googleapiclient.discovery.Resource):
        def get(
            self, *, project: str, operation: str, **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def list(
            self,
            *,
            project: str,
            instance: str = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> OperationsListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: OperationsListResponseHttpRequest,
            previous_response: OperationsListResponse,
        ) -> OperationsListResponseHttpRequest | None: ...

    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class InstancesResource(googleapiclient.discovery.Resource):
            def rescheduleMaintenance(
                self,
                *,
                project: str,
                instance: str,
                body: SqlInstancesRescheduleMaintenanceRequestBody = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def startExternalSync(
                self,
                *,
                project: str,
                instance: str,
                body: SqlInstancesStartExternalSyncRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def verifyExternalSyncSettings(
                self,
                *,
                project: str,
                instance: str,
                body: SqlInstancesVerifyExternalSyncSettingsRequest = ...,
                **kwargs: typing.Any
            ) -> SqlInstancesVerifyExternalSyncSettingsResponseHttpRequest: ...

        def instances(self) -> InstancesResource: ...

    @typing.type_check_only
    class SslCertsResource(googleapiclient.discovery.Resource):
        def createEphemeral(
            self,
            *,
            project: str,
            instance: str,
            body: SslCertsCreateEphemeralRequest = ...,
            **kwargs: typing.Any
        ) -> SslCertHttpRequest: ...
        def delete(
            self,
            *,
            project: str,
            instance: str,
            sha1Fingerprint: str,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def get(
            self,
            *,
            project: str,
            instance: str,
            sha1Fingerprint: str,
            **kwargs: typing.Any
        ) -> SslCertHttpRequest: ...
        def insert(
            self,
            *,
            project: str,
            instance: str,
            body: SslCertsInsertRequest = ...,
            **kwargs: typing.Any
        ) -> SslCertsInsertResponseHttpRequest: ...
        def list(
            self, *, project: str, instance: str, **kwargs: typing.Any
        ) -> SslCertsListResponseHttpRequest: ...

    @typing.type_check_only
    class TiersResource(googleapiclient.discovery.Resource):
        def list(
            self, *, project: str, **kwargs: typing.Any
        ) -> TiersListResponseHttpRequest: ...

    @typing.type_check_only
    class UsersResource(googleapiclient.discovery.Resource):
        def delete(
            self,
            *,
            project: str,
            instance: str,
            host: str = ...,
            name: str = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def get(
            self, *, project: str, instance: str, name: str, **kwargs: typing.Any
        ) -> UserHttpRequest: ...
        def insert(
            self, *, project: str, instance: str, body: User = ..., **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def list(
            self, *, project: str, instance: str, **kwargs: typing.Any
        ) -> UsersListResponseHttpRequest: ...
        def update(
            self,
            *,
            project: str,
            instance: str,
            body: User = ...,
            host: str = ...,
            name: str = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def backupRuns(self) -> BackupRunsResource: ...
    def connect(self) -> ConnectResource: ...
    def databases(self) -> DatabasesResource: ...
    def flags(self) -> FlagsResource: ...
    def instances(self) -> InstancesResource: ...
    def operations(self) -> OperationsResource: ...
    def projects(self) -> ProjectsResource: ...
    def sslCerts(self) -> SslCertsResource: ...
    def tiers(self) -> TiersResource: ...
    def users(self) -> UsersResource: ...

@typing.type_check_only
class BackupRunHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BackupRun: ...

@typing.type_check_only
class BackupRunsListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BackupRunsListResponse: ...

@typing.type_check_only
class ConnectSettingsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ConnectSettings: ...

@typing.type_check_only
class DatabaseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Database: ...

@typing.type_check_only
class DatabaseInstanceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DatabaseInstance: ...

@typing.type_check_only
class DatabasesListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DatabasesListResponse: ...

@typing.type_check_only
class FlagsListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> FlagsListResponse: ...

@typing.type_check_only
class GenerateEphemeralCertResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GenerateEphemeralCertResponse: ...

@typing.type_check_only
class InstancesListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> InstancesListResponse: ...

@typing.type_check_only
class InstancesListServerCasResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> InstancesListServerCasResponse: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class OperationsListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OperationsListResponse: ...

@typing.type_check_only
class SqlInstancesVerifyExternalSyncSettingsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SqlInstancesVerifyExternalSyncSettingsResponse: ...

@typing.type_check_only
class SslCertHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SslCert: ...

@typing.type_check_only
class SslCertsInsertResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SslCertsInsertResponse: ...

@typing.type_check_only
class SslCertsListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SslCertsListResponse: ...

@typing.type_check_only
class TiersListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TiersListResponse: ...

@typing.type_check_only
class UserHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> User: ...

@typing.type_check_only
class UsersListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> UsersListResponse: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class DriveResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AboutResource(googleapiclient.discovery.Resource):
        def get(
            self,
            *,
            includeSubscribed: bool = ...,
            maxChangeIdCount: str = ...,
            startChangeId: str = ...,
            **kwargs: typing.Any
        ) -> AboutHttpRequest: ...

    @typing.type_check_only
    class AppsResource(googleapiclient.discovery.Resource):
        def get(self, *, appId: str, **kwargs: typing.Any) -> AppHttpRequest: ...
        def list(
            self,
            *,
            appFilterExtensions: str = ...,
            appFilterMimeTypes: str = ...,
            languageCode: str = ...,
            **kwargs: typing.Any
        ) -> AppListHttpRequest: ...

    @typing.type_check_only
    class ChangesResource(googleapiclient.discovery.Resource):
        def get(
            self,
            *,
            changeId: str,
            driveId: str = ...,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            teamDriveId: str = ...,
            **kwargs: typing.Any
        ) -> ChangeHttpRequest: ...
        def getStartPageToken(
            self,
            *,
            driveId: str = ...,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            teamDriveId: str = ...,
            **kwargs: typing.Any
        ) -> StartPageTokenHttpRequest: ...
        def list(
            self,
            *,
            driveId: str = ...,
            includeCorpusRemovals: bool = ...,
            includeDeleted: bool = ...,
            includeItemsFromAllDrives: bool = ...,
            includeLabels: str = ...,
            includePermissionsForView: str = ...,
            includeSubscribed: bool = ...,
            includeTeamDriveItems: bool = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            spaces: str = ...,
            startChangeId: str = ...,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            teamDriveId: str = ...,
            **kwargs: typing.Any
        ) -> ChangeListHttpRequest: ...
        def list_next(
            self, previous_request: ChangeListHttpRequest, previous_response: ChangeList
        ) -> ChangeListHttpRequest | None: ...
        def watch(
            self,
            *,
            body: Channel = ...,
            driveId: str = ...,
            includeCorpusRemovals: bool = ...,
            includeDeleted: bool = ...,
            includeItemsFromAllDrives: bool = ...,
            includeLabels: str = ...,
            includePermissionsForView: str = ...,
            includeSubscribed: bool = ...,
            includeTeamDriveItems: bool = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            spaces: str = ...,
            startChangeId: str = ...,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            teamDriveId: str = ...,
            **kwargs: typing.Any
        ) -> ChannelHttpRequest: ...

    @typing.type_check_only
    class ChannelsResource(googleapiclient.discovery.Resource):
        def stop(
            self, *, body: Channel = ..., **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...

    @typing.type_check_only
    class ChildrenResource(googleapiclient.discovery.Resource):
        def delete(
            self,
            *,
            folderId: str,
            childId: str,
            enforceSingleParent: bool = ...,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, folderId: str, childId: str, **kwargs: typing.Any
        ) -> ChildReferenceHttpRequest: ...
        def insert(
            self,
            *,
            folderId: str,
            body: ChildReference = ...,
            enforceSingleParent: bool = ...,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            **kwargs: typing.Any
        ) -> ChildReferenceHttpRequest: ...
        def list(
            self,
            *,
            folderId: str,
            maxResults: int = ...,
            orderBy: str = ...,
            pageToken: str = ...,
            q: str = ...,
            **kwargs: typing.Any
        ) -> ChildListHttpRequest: ...
        def list_next(
            self, previous_request: ChildListHttpRequest, previous_response: ChildList
        ) -> ChildListHttpRequest | None: ...

    @typing.type_check_only
    class CommentsResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, fileId: str, commentId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self,
            *,
            fileId: str,
            commentId: str,
            includeDeleted: bool = ...,
            **kwargs: typing.Any
        ) -> CommentHttpRequest: ...
        def insert(
            self, *, fileId: str, body: Comment = ..., **kwargs: typing.Any
        ) -> CommentHttpRequest: ...
        def list(
            self,
            *,
            fileId: str,
            includeDeleted: bool = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            updatedMin: str = ...,
            **kwargs: typing.Any
        ) -> CommentListHttpRequest: ...
        def list_next(
            self,
            previous_request: CommentListHttpRequest,
            previous_response: CommentList,
        ) -> CommentListHttpRequest | None: ...
        def patch(
            self,
            *,
            fileId: str,
            commentId: str,
            body: Comment = ...,
            **kwargs: typing.Any
        ) -> CommentHttpRequest: ...
        def update(
            self,
            *,
            fileId: str,
            commentId: str,
            body: Comment = ...,
            **kwargs: typing.Any
        ) -> CommentHttpRequest: ...

    @typing.type_check_only
    class DrivesResource(googleapiclient.discovery.Resource):
        def delete(
            self,
            *,
            driveId: str,
            allowItemDeletion: bool = ...,
            useDomainAdminAccess: bool = ...,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self,
            *,
            driveId: str,
            useDomainAdminAccess: bool = ...,
            **kwargs: typing.Any
        ) -> DriveHttpRequest: ...
        def hide(self, *, driveId: str, **kwargs: typing.Any) -> DriveHttpRequest: ...
        def insert(
            self, *, requestId: str, body: Drive = ..., **kwargs: typing.Any
        ) -> DriveHttpRequest: ...
        def list(
            self,
            *,
            maxResults: int = ...,
            pageToken: str = ...,
            q: str = ...,
            useDomainAdminAccess: bool = ...,
            **kwargs: typing.Any
        ) -> DriveListHttpRequest: ...
        def list_next(
            self, previous_request: DriveListHttpRequest, previous_response: DriveList
        ) -> DriveListHttpRequest | None: ...
        def unhide(self, *, driveId: str, **kwargs: typing.Any) -> DriveHttpRequest: ...
        def update(
            self,
            *,
            driveId: str,
            body: Drive = ...,
            useDomainAdminAccess: bool = ...,
            **kwargs: typing.Any
        ) -> DriveHttpRequest: ...

    @typing.type_check_only
    class FilesResource(googleapiclient.discovery.Resource):
        def copy(
            self,
            *,
            fileId: str,
            body: File = ...,
            convert: bool = ...,
            enforceSingleParent: bool = ...,
            includeLabels: str = ...,
            includePermissionsForView: str = ...,
            ocr: bool = ...,
            ocrLanguage: str = ...,
            pinned: bool = ...,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            timedTextLanguage: str = ...,
            timedTextTrackName: str = ...,
            visibility: typing_extensions.Literal["DEFAULT", "PRIVATE"] = ...,
            **kwargs: typing.Any
        ) -> FileHttpRequest: ...
        def delete(
            self,
            *,
            fileId: str,
            enforceSingleParent: bool = ...,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def emptyTrash(
            self, *, enforceSingleParent: bool = ..., **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def export(
            self, *, fileId: str, mimeType: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def export_media(
            self, *, fileId: str, mimeType: str, **kwargs: typing.Any
        ) -> BytesHttpRequest: ...
        def generateIds(
            self,
            *,
            maxResults: int = ...,
            space: str = ...,
            type: str = ...,
            **kwargs: typing.Any
        ) -> GeneratedIdsHttpRequest: ...
        def get(
            self,
            *,
            fileId: str,
            acknowledgeAbuse: bool = ...,
            includeLabels: str = ...,
            includePermissionsForView: str = ...,
            projection: typing_extensions.Literal["BASIC", "FULL"] = ...,
            revisionId: str = ...,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            updateViewedDate: bool = ...,
            **kwargs: typing.Any
        ) -> FileHttpRequest: ...
        def get_media(
            self,
            *,
            fileId: str,
            acknowledgeAbuse: bool = ...,
            includeLabels: str = ...,
            includePermissionsForView: str = ...,
            projection: typing_extensions.Literal["BASIC", "FULL"] = ...,
            revisionId: str = ...,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            updateViewedDate: bool = ...,
            **kwargs: typing.Any
        ) -> BytesHttpRequest: ...
        def insert(
            self,
            *,
            body: File = ...,
            convert: bool = ...,
            enforceSingleParent: bool = ...,
            includeLabels: str = ...,
            includePermissionsForView: str = ...,
            ocr: bool = ...,
            ocrLanguage: str = ...,
            pinned: bool = ...,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            timedTextLanguage: str = ...,
            timedTextTrackName: str = ...,
            useContentAsIndexableText: bool = ...,
            visibility: typing_extensions.Literal["DEFAULT", "PRIVATE"] = ...,
            **kwargs: typing.Any
        ) -> FileHttpRequest: ...
        def list(
            self,
            *,
            corpora: str = ...,
            corpus: typing_extensions.Literal["DEFAULT", "DOMAIN"] = ...,
            driveId: str = ...,
            includeItemsFromAllDrives: bool = ...,
            includeLabels: str = ...,
            includePermissionsForView: str = ...,
            includeTeamDriveItems: bool = ...,
            maxResults: int = ...,
            orderBy: str = ...,
            pageToken: str = ...,
            projection: typing_extensions.Literal["BASIC", "FULL"] = ...,
            q: str = ...,
            spaces: str = ...,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            teamDriveId: str = ...,
            **kwargs: typing.Any
        ) -> FileListHttpRequest: ...
        def list_next(
            self, previous_request: FileListHttpRequest, previous_response: FileList
        ) -> FileListHttpRequest | None: ...
        def listLabels(
            self,
            *,
            fileId: str,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> LabelListHttpRequest: ...
        def listLabels_next(
            self, previous_request: LabelListHttpRequest, previous_response: LabelList
        ) -> LabelListHttpRequest | None: ...
        def modifyLabels(
            self, *, fileId: str, body: ModifyLabelsRequest = ..., **kwargs: typing.Any
        ) -> ModifyLabelsResponseHttpRequest: ...
        def patch(
            self,
            *,
            fileId: str,
            body: File = ...,
            addParents: str = ...,
            convert: bool = ...,
            enforceSingleParent: bool = ...,
            includeLabels: str = ...,
            includePermissionsForView: str = ...,
            modifiedDateBehavior: typing_extensions.Literal[
                "fromBody",
                "fromBodyIfNeeded",
                "fromBodyOrNow",
                "noChange",
                "now",
                "nowIfNeeded",
            ] = ...,
            newRevision: bool = ...,
            ocr: bool = ...,
            ocrLanguage: str = ...,
            pinned: bool = ...,
            removeParents: str = ...,
            setModifiedDate: bool = ...,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            timedTextLanguage: str = ...,
            timedTextTrackName: str = ...,
            updateViewedDate: bool = ...,
            useContentAsIndexableText: bool = ...,
            **kwargs: typing.Any
        ) -> FileHttpRequest: ...
        def touch(
            self,
            *,
            fileId: str,
            includeLabels: str = ...,
            includePermissionsForView: str = ...,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            **kwargs: typing.Any
        ) -> FileHttpRequest: ...
        def trash(
            self,
            *,
            fileId: str,
            includeLabels: str = ...,
            includePermissionsForView: str = ...,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            **kwargs: typing.Any
        ) -> FileHttpRequest: ...
        def untrash(
            self,
            *,
            fileId: str,
            includeLabels: str = ...,
            includePermissionsForView: str = ...,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            **kwargs: typing.Any
        ) -> FileHttpRequest: ...
        def update(
            self,
            *,
            fileId: str,
            body: File = ...,
            addParents: str = ...,
            convert: bool = ...,
            enforceSingleParent: bool = ...,
            includeLabels: str = ...,
            includePermissionsForView: str = ...,
            modifiedDateBehavior: typing_extensions.Literal[
                "fromBody",
                "fromBodyIfNeeded",
                "fromBodyOrNow",
                "noChange",
                "now",
                "nowIfNeeded",
            ] = ...,
            newRevision: bool = ...,
            ocr: bool = ...,
            ocrLanguage: str = ...,
            pinned: bool = ...,
            removeParents: str = ...,
            setModifiedDate: bool = ...,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            timedTextLanguage: str = ...,
            timedTextTrackName: str = ...,
            updateViewedDate: bool = ...,
            useContentAsIndexableText: bool = ...,
            **kwargs: typing.Any
        ) -> FileHttpRequest: ...
        def watch(
            self,
            *,
            fileId: str,
            body: Channel = ...,
            acknowledgeAbuse: bool = ...,
            includeLabels: str = ...,
            includePermissionsForView: str = ...,
            projection: typing_extensions.Literal["BASIC", "FULL"] = ...,
            revisionId: str = ...,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            updateViewedDate: bool = ...,
            **kwargs: typing.Any
        ) -> ChannelHttpRequest: ...
        def watch_media(
            self,
            *,
            fileId: str,
            body: Channel = ...,
            acknowledgeAbuse: bool = ...,
            includeLabels: str = ...,
            includePermissionsForView: str = ...,
            projection: typing_extensions.Literal["BASIC", "FULL"] = ...,
            revisionId: str = ...,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            updateViewedDate: bool = ...,
            **kwargs: typing.Any
        ) -> BytesHttpRequest: ...

    @typing.type_check_only
    class ParentsResource(googleapiclient.discovery.Resource):
        def delete(
            self,
            *,
            fileId: str,
            parentId: str,
            enforceSingleParent: bool = ...,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, fileId: str, parentId: str, **kwargs: typing.Any
        ) -> ParentReferenceHttpRequest: ...
        def insert(
            self,
            *,
            fileId: str,
            body: ParentReference = ...,
            enforceSingleParent: bool = ...,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            **kwargs: typing.Any
        ) -> ParentReferenceHttpRequest: ...
        def list(
            self, *, fileId: str, **kwargs: typing.Any
        ) -> ParentListHttpRequest: ...

    @typing.type_check_only
    class PermissionsResource(googleapiclient.discovery.Resource):
        def delete(
            self,
            *,
            fileId: str,
            permissionId: str,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            useDomainAdminAccess: bool = ...,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self,
            *,
            fileId: str,
            permissionId: str,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            useDomainAdminAccess: bool = ...,
            **kwargs: typing.Any
        ) -> PermissionHttpRequest: ...
        def getIdForEmail(
            self, *, email: str, **kwargs: typing.Any
        ) -> PermissionIdHttpRequest: ...
        def insert(
            self,
            *,
            fileId: str,
            body: Permission = ...,
            emailMessage: str = ...,
            enforceSingleParent: bool = ...,
            moveToNewOwnersRoot: bool = ...,
            sendNotificationEmails: bool = ...,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            useDomainAdminAccess: bool = ...,
            **kwargs: typing.Any
        ) -> PermissionHttpRequest: ...
        def list(
            self,
            *,
            fileId: str,
            includePermissionsForView: str = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            useDomainAdminAccess: bool = ...,
            **kwargs: typing.Any
        ) -> PermissionListHttpRequest: ...
        def list_next(
            self,
            previous_request: PermissionListHttpRequest,
            previous_response: PermissionList,
        ) -> PermissionListHttpRequest | None: ...
        def patch(
            self,
            *,
            fileId: str,
            permissionId: str,
            body: Permission = ...,
            removeExpiration: bool = ...,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            transferOwnership: bool = ...,
            useDomainAdminAccess: bool = ...,
            **kwargs: typing.Any
        ) -> PermissionHttpRequest: ...
        def update(
            self,
            *,
            fileId: str,
            permissionId: str,
            body: Permission = ...,
            removeExpiration: bool = ...,
            supportsAllDrives: bool = ...,
            supportsTeamDrives: bool = ...,
            transferOwnership: bool = ...,
            useDomainAdminAccess: bool = ...,
            **kwargs: typing.Any
        ) -> PermissionHttpRequest: ...

    @typing.type_check_only
    class PropertiesResource(googleapiclient.discovery.Resource):
        def delete(
            self,
            *,
            fileId: str,
            propertyKey: str,
            visibility: str = ...,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self,
            *,
            fileId: str,
            propertyKey: str,
            visibility: str = ...,
            **kwargs: typing.Any
        ) -> PropertyHttpRequest: ...
        def insert(
            self, *, fileId: str, body: Property = ..., **kwargs: typing.Any
        ) -> PropertyHttpRequest: ...
        def list(
            self, *, fileId: str, **kwargs: typing.Any
        ) -> PropertyListHttpRequest: ...
        def patch(
            self,
            *,
            fileId: str,
            propertyKey: str,
            body: Property = ...,
            visibility: str = ...,
            **kwargs: typing.Any
        ) -> PropertyHttpRequest: ...
        def update(
            self,
            *,
            fileId: str,
            propertyKey: str,
            body: Property = ...,
            visibility: str = ...,
            **kwargs: typing.Any
        ) -> PropertyHttpRequest: ...

    @typing.type_check_only
    class RepliesResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, fileId: str, commentId: str, replyId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self,
            *,
            fileId: str,
            commentId: str,
            replyId: str,
            includeDeleted: bool = ...,
            **kwargs: typing.Any
        ) -> CommentReplyHttpRequest: ...
        def insert(
            self,
            *,
            fileId: str,
            commentId: str,
            body: CommentReply = ...,
            **kwargs: typing.Any
        ) -> CommentReplyHttpRequest: ...
        def list(
            self,
            *,
            fileId: str,
            commentId: str,
            includeDeleted: bool = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> CommentReplyListHttpRequest: ...
        def list_next(
            self,
            previous_request: CommentReplyListHttpRequest,
            previous_response: CommentReplyList,
        ) -> CommentReplyListHttpRequest | None: ...
        def patch(
            self,
            *,
            fileId: str,
            commentId: str,
            replyId: str,
            body: CommentReply = ...,
            **kwargs: typing.Any
        ) -> CommentReplyHttpRequest: ...
        def update(
            self,
            *,
            fileId: str,
            commentId: str,
            replyId: str,
            body: CommentReply = ...,
            **kwargs: typing.Any
        ) -> CommentReplyHttpRequest: ...

    @typing.type_check_only
    class RevisionsResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, fileId: str, revisionId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, fileId: str, revisionId: str, **kwargs: typing.Any
        ) -> RevisionHttpRequest: ...
        def list(
            self,
            *,
            fileId: str,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> RevisionListHttpRequest: ...
        def list_next(
            self,
            previous_request: RevisionListHttpRequest,
            previous_response: RevisionList,
        ) -> RevisionListHttpRequest | None: ...
        def patch(
            self,
            *,
            fileId: str,
            revisionId: str,
            body: Revision = ...,
            **kwargs: typing.Any
        ) -> RevisionHttpRequest: ...
        def update(
            self,
            *,
            fileId: str,
            revisionId: str,
            body: Revision = ...,
            **kwargs: typing.Any
        ) -> RevisionHttpRequest: ...

    @typing.type_check_only
    class TeamdrivesResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, teamDriveId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self,
            *,
            teamDriveId: str,
            useDomainAdminAccess: bool = ...,
            **kwargs: typing.Any
        ) -> TeamDriveHttpRequest: ...
        def insert(
            self, *, requestId: str, body: TeamDrive = ..., **kwargs: typing.Any
        ) -> TeamDriveHttpRequest: ...
        def list(
            self,
            *,
            maxResults: int = ...,
            pageToken: str = ...,
            q: str = ...,
            useDomainAdminAccess: bool = ...,
            **kwargs: typing.Any
        ) -> TeamDriveListHttpRequest: ...
        def list_next(
            self,
            previous_request: TeamDriveListHttpRequest,
            previous_response: TeamDriveList,
        ) -> TeamDriveListHttpRequest | None: ...
        def update(
            self,
            *,
            teamDriveId: str,
            body: TeamDrive = ...,
            useDomainAdminAccess: bool = ...,
            **kwargs: typing.Any
        ) -> TeamDriveHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def about(self) -> AboutResource: ...
    def apps(self) -> AppsResource: ...
    def changes(self) -> ChangesResource: ...
    def channels(self) -> ChannelsResource: ...
    def children(self) -> ChildrenResource: ...
    def comments(self) -> CommentsResource: ...
    def drives(self) -> DrivesResource: ...
    def files(self) -> FilesResource: ...
    def parents(self) -> ParentsResource: ...
    def permissions(self) -> PermissionsResource: ...
    def properties(self) -> PropertiesResource: ...
    def replies(self) -> RepliesResource: ...
    def revisions(self) -> RevisionsResource: ...
    def teamdrives(self) -> TeamdrivesResource: ...

@typing.type_check_only
class AboutHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> About: ...

@typing.type_check_only
class AppHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> App: ...

@typing.type_check_only
class AppListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AppList: ...

@typing.type_check_only
class ChangeHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Change: ...

@typing.type_check_only
class ChangeListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ChangeList: ...

@typing.type_check_only
class ChannelHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Channel: ...

@typing.type_check_only
class ChildListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ChildList: ...

@typing.type_check_only
class ChildReferenceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ChildReference: ...

@typing.type_check_only
class CommentHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Comment: ...

@typing.type_check_only
class CommentListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CommentList: ...

@typing.type_check_only
class CommentReplyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CommentReply: ...

@typing.type_check_only
class CommentReplyListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CommentReplyList: ...

@typing.type_check_only
class DriveHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Drive: ...

@typing.type_check_only
class DriveListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DriveList: ...

@typing.type_check_only
class FileHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> File: ...

@typing.type_check_only
class FileListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> FileList: ...

@typing.type_check_only
class GeneratedIdsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GeneratedIds: ...

@typing.type_check_only
class LabelListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LabelList: ...

@typing.type_check_only
class ModifyLabelsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ModifyLabelsResponse: ...

@typing.type_check_only
class ParentListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ParentList: ...

@typing.type_check_only
class ParentReferenceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ParentReference: ...

@typing.type_check_only
class PermissionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Permission: ...

@typing.type_check_only
class PermissionIdHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PermissionId: ...

@typing.type_check_only
class PermissionListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PermissionList: ...

@typing.type_check_only
class PropertyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Property: ...

@typing.type_check_only
class PropertyListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PropertyList: ...

@typing.type_check_only
class RevisionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Revision: ...

@typing.type_check_only
class RevisionListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> RevisionList: ...

@typing.type_check_only
class StartPageTokenHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> StartPageToken: ...

@typing.type_check_only
class TeamDriveHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TeamDrive: ...

@typing.type_check_only
class TeamDriveListHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TeamDriveList: ...

@typing.type_check_only
class BytesHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> bytes: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Binding(typing_extensions.TypedDict, total=False):
    condition: Expr
    members: _list[str]
    role: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class GetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    options: GetPolicyOptions

@typing.type_check_only
class GetPolicyOptions(typing_extensions.TypedDict, total=False):
    requestedPolicyVersion: int

@typing.type_check_only
class GoogleCloudDatacatalogV1BigQueryConnectionSpec(
    typing_extensions.TypedDict, total=False
):
    cloudSql: GoogleCloudDatacatalogV1CloudSqlBigQueryConnectionSpec
    connectionType: typing_extensions.Literal[
        "CONNECTION_TYPE_UNSPECIFIED", "CLOUD_SQL"
    ]
    hasCredential: bool

@typing.type_check_only
class GoogleCloudDatacatalogV1BigQueryDateShardedSpec(
    typing_extensions.TypedDict, total=False
):
    dataset: str
    latestShardResource: str
    shardCount: str
    tablePrefix: str

@typing.type_check_only
class GoogleCloudDatacatalogV1BigQueryRoutineSpec(
    typing_extensions.TypedDict, total=False
):
    importedLibraries: _list[str]

@typing.type_check_only
class GoogleCloudDatacatalogV1BigQueryTableSpec(
    typing_extensions.TypedDict, total=False
):
    tableSourceType: typing_extensions.Literal[
        "TABLE_SOURCE_TYPE_UNSPECIFIED",
        "BIGQUERY_VIEW",
        "BIGQUERY_TABLE",
        "BIGQUERY_MATERIALIZED_VIEW",
    ]
    tableSpec: GoogleCloudDatacatalogV1TableSpec
    viewSpec: GoogleCloudDatacatalogV1ViewSpec

@typing.type_check_only
class GoogleCloudDatacatalogV1BusinessContext(typing_extensions.TypedDict, total=False):
    contacts: GoogleCloudDatacatalogV1Contacts
    entryOverview: GoogleCloudDatacatalogV1EntryOverview

@typing.type_check_only
class GoogleCloudDatacatalogV1CloudSqlBigQueryConnectionSpec(
    typing_extensions.TypedDict, total=False
):
    database: str
    instanceId: str
    type: typing_extensions.Literal["DATABASE_TYPE_UNSPECIFIED", "POSTGRES", "MYSQL"]

@typing.type_check_only
class GoogleCloudDatacatalogV1ColumnSchema(typing_extensions.TypedDict, total=False):
    column: str
    description: str
    lookerColumnSpec: GoogleCloudDatacatalogV1ColumnSchemaLookerColumnSpec
    mode: str
    subcolumns: _list[GoogleCloudDatacatalogV1ColumnSchema]
    type: str

@typing.type_check_only
class GoogleCloudDatacatalogV1ColumnSchemaLookerColumnSpec(
    typing_extensions.TypedDict, total=False
):
    type: typing_extensions.Literal[
        "LOOKER_COLUMN_TYPE_UNSPECIFIED",
        "DIMENSION",
        "DIMENSION_GROUP",
        "FILTER",
        "MEASURE",
        "PAREMETER",
    ]

@typing.type_check_only
class GoogleCloudDatacatalogV1Contacts(typing_extensions.TypedDict, total=False):
    people: _list[GoogleCloudDatacatalogV1ContactsPerson]

@typing.type_check_only
class GoogleCloudDatacatalogV1ContactsPerson(typing_extensions.TypedDict, total=False):
    designation: str
    email: str

@typing.type_check_only
class GoogleCloudDatacatalogV1CrossRegionalSource(
    typing_extensions.TypedDict, total=False
):
    taxonomy: str

@typing.type_check_only
class GoogleCloudDatacatalogV1DataSource(typing_extensions.TypedDict, total=False):
    resource: str
    service: typing_extensions.Literal[
        "SERVICE_UNSPECIFIED", "CLOUD_STORAGE", "BIGQUERY"
    ]
    sourceEntry: str
    storageProperties: GoogleCloudDatacatalogV1StorageProperties

@typing.type_check_only
class GoogleCloudDatacatalogV1DataSourceConnectionSpec(
    typing_extensions.TypedDict, total=False
):
    bigqueryConnectionSpec: GoogleCloudDatacatalogV1BigQueryConnectionSpec

@typing.type_check_only
class GoogleCloudDatacatalogV1DatabaseTableSpec(
    typing_extensions.TypedDict, total=False
):
    dataplexTable: GoogleCloudDatacatalogV1DataplexTableSpec
    type: typing_extensions.Literal["TABLE_TYPE_UNSPECIFIED", "NATIVE", "EXTERNAL"]

@typing.type_check_only
class GoogleCloudDatacatalogV1DataplexExternalTable(
    typing_extensions.TypedDict, total=False
):
    dataCatalogEntry: str
    fullyQualifiedName: str
    googleCloudResource: str
    system: typing_extensions.Literal[
        "INTEGRATED_SYSTEM_UNSPECIFIED",
        "BIGQUERY",
        "CLOUD_PUBSUB",
        "DATAPROC_METASTORE",
        "DATAPLEX",
    ]

@typing.type_check_only
class GoogleCloudDatacatalogV1DataplexFilesetSpec(
    typing_extensions.TypedDict, total=False
):
    dataplexSpec: GoogleCloudDatacatalogV1DataplexSpec

@typing.type_check_only
class GoogleCloudDatacatalogV1DataplexSpec(typing_extensions.TypedDict, total=False):
    asset: str
    compressionFormat: str
    dataFormat: GoogleCloudDatacatalogV1PhysicalSchema
    projectId: str

@typing.type_check_only
class GoogleCloudDatacatalogV1DataplexTableSpec(
    typing_extensions.TypedDict, total=False
):
    dataplexSpec: GoogleCloudDatacatalogV1DataplexSpec
    externalTables: _list[GoogleCloudDatacatalogV1DataplexExternalTable]
    userManaged: bool

@typing.type_check_only
class GoogleCloudDatacatalogV1Entry(typing_extensions.TypedDict, total=False):
    bigqueryDateShardedSpec: GoogleCloudDatacatalogV1BigQueryDateShardedSpec
    bigqueryTableSpec: GoogleCloudDatacatalogV1BigQueryTableSpec
    businessContext: GoogleCloudDatacatalogV1BusinessContext
    dataSource: GoogleCloudDatacatalogV1DataSource
    dataSourceConnectionSpec: GoogleCloudDatacatalogV1DataSourceConnectionSpec
    databaseTableSpec: GoogleCloudDatacatalogV1DatabaseTableSpec
    description: str
    displayName: str
    filesetSpec: GoogleCloudDatacatalogV1FilesetSpec
    fullyQualifiedName: str
    gcsFilesetSpec: GoogleCloudDatacatalogV1GcsFilesetSpec
    integratedSystem: typing_extensions.Literal[
        "INTEGRATED_SYSTEM_UNSPECIFIED",
        "BIGQUERY",
        "CLOUD_PUBSUB",
        "DATAPROC_METASTORE",
        "DATAPLEX",
    ]
    labels: dict[str, typing.Any]
    linkedResource: str
    name: str
    personalDetails: GoogleCloudDatacatalogV1PersonalDetails
    routineSpec: GoogleCloudDatacatalogV1RoutineSpec
    schema: GoogleCloudDatacatalogV1Schema
    sourceSystemTimestamps: GoogleCloudDatacatalogV1SystemTimestamps
    type: typing_extensions.Literal[
        "ENTRY_TYPE_UNSPECIFIED",
        "TABLE",
        "MODEL",
        "DATA_STREAM",
        "FILESET",
        "CLUSTER",
        "DATABASE",
        "DATA_SOURCE_CONNECTION",
        "ROUTINE",
        "LAKE",
        "ZONE",
        "SERVICE",
    ]
    usageSignal: GoogleCloudDatacatalogV1UsageSignal
    userSpecifiedSystem: str
    userSpecifiedType: str

@typing.type_check_only
class GoogleCloudDatacatalogV1EntryGroup(typing_extensions.TypedDict, total=False):
    dataCatalogTimestamps: GoogleCloudDatacatalogV1SystemTimestamps
    description: str
    displayName: str
    name: str

@typing.type_check_only
class GoogleCloudDatacatalogV1EntryOverview(typing_extensions.TypedDict, total=False):
    overview: str

@typing.type_check_only
class GoogleCloudDatacatalogV1ExportTaxonomiesResponse(
    typing_extensions.TypedDict, total=False
):
    taxonomies: _list[GoogleCloudDatacatalogV1SerializedTaxonomy]

@typing.type_check_only
class GoogleCloudDatacatalogV1FieldType(typing_extensions.TypedDict, total=False):
    enumType: GoogleCloudDatacatalogV1FieldTypeEnumType
    primitiveType: typing_extensions.Literal[
        "PRIMITIVE_TYPE_UNSPECIFIED",
        "DOUBLE",
        "STRING",
        "BOOL",
        "TIMESTAMP",
        "RICHTEXT",
    ]

@typing.type_check_only
class GoogleCloudDatacatalogV1FieldTypeEnumType(
    typing_extensions.TypedDict, total=False
):
    allowedValues: _list[GoogleCloudDatacatalogV1FieldTypeEnumTypeEnumValue]

@typing.type_check_only
class GoogleCloudDatacatalogV1FieldTypeEnumTypeEnumValue(
    typing_extensions.TypedDict, total=False
):
    displayName: str

@typing.type_check_only
class GoogleCloudDatacatalogV1FilesetSpec(typing_extensions.TypedDict, total=False):
    dataplexFileset: GoogleCloudDatacatalogV1DataplexFilesetSpec

@typing.type_check_only
class GoogleCloudDatacatalogV1GcsFileSpec(typing_extensions.TypedDict, total=False):
    filePath: str
    gcsTimestamps: GoogleCloudDatacatalogV1SystemTimestamps
    sizeBytes: str

@typing.type_check_only
class GoogleCloudDatacatalogV1GcsFilesetSpec(typing_extensions.TypedDict, total=False):
    filePatterns: _list[str]
    sampleGcsFileSpecs: _list[GoogleCloudDatacatalogV1GcsFileSpec]

@typing.type_check_only
class GoogleCloudDatacatalogV1ImportTaxonomiesRequest(
    typing_extensions.TypedDict, total=False
):
    crossRegionalSource: GoogleCloudDatacatalogV1CrossRegionalSource
    inlineSource: GoogleCloudDatacatalogV1InlineSource

@typing.type_check_only
class GoogleCloudDatacatalogV1ImportTaxonomiesResponse(
    typing_extensions.TypedDict, total=False
):
    taxonomies: _list[GoogleCloudDatacatalogV1Taxonomy]

@typing.type_check_only
class GoogleCloudDatacatalogV1InlineSource(typing_extensions.TypedDict, total=False):
    taxonomies: _list[GoogleCloudDatacatalogV1SerializedTaxonomy]

@typing.type_check_only
class GoogleCloudDatacatalogV1ListEntriesResponse(
    typing_extensions.TypedDict, total=False
):
    entries: _list[GoogleCloudDatacatalogV1Entry]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudDatacatalogV1ListEntryGroupsResponse(
    typing_extensions.TypedDict, total=False
):
    entryGroups: _list[GoogleCloudDatacatalogV1EntryGroup]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudDatacatalogV1ListPolicyTagsResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    policyTags: _list[GoogleCloudDatacatalogV1PolicyTag]

@typing.type_check_only
class GoogleCloudDatacatalogV1ListTagsResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    tags: _list[GoogleCloudDatacatalogV1Tag]

@typing.type_check_only
class GoogleCloudDatacatalogV1ListTaxonomiesResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    taxonomies: _list[GoogleCloudDatacatalogV1Taxonomy]

@typing.type_check_only
class GoogleCloudDatacatalogV1ModifyEntryContactsRequest(
    typing_extensions.TypedDict, total=False
):
    contacts: GoogleCloudDatacatalogV1Contacts

@typing.type_check_only
class GoogleCloudDatacatalogV1ModifyEntryOverviewRequest(
    typing_extensions.TypedDict, total=False
):
    entryOverview: GoogleCloudDatacatalogV1EntryOverview

@typing.type_check_only
class GoogleCloudDatacatalogV1PersonalDetails(typing_extensions.TypedDict, total=False):
    starTime: str
    starred: bool

@typing.type_check_only
class GoogleCloudDatacatalogV1PhysicalSchema(typing_extensions.TypedDict, total=False):
    avro: GoogleCloudDatacatalogV1PhysicalSchemaAvroSchema
    csv: GoogleCloudDatacatalogV1PhysicalSchemaCsvSchema
    orc: GoogleCloudDatacatalogV1PhysicalSchemaOrcSchema
    parquet: GoogleCloudDatacatalogV1PhysicalSchemaParquetSchema
    protobuf: GoogleCloudDatacatalogV1PhysicalSchemaProtobufSchema
    thrift: GoogleCloudDatacatalogV1PhysicalSchemaThriftSchema

@typing.type_check_only
class GoogleCloudDatacatalogV1PhysicalSchemaAvroSchema(
    typing_extensions.TypedDict, total=False
):
    text: str

@typing.type_check_only
class GoogleCloudDatacatalogV1PhysicalSchemaCsvSchema(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudDatacatalogV1PhysicalSchemaOrcSchema(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudDatacatalogV1PhysicalSchemaParquetSchema(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudDatacatalogV1PhysicalSchemaProtobufSchema(
    typing_extensions.TypedDict, total=False
):
    text: str

@typing.type_check_only
class GoogleCloudDatacatalogV1PhysicalSchemaThriftSchema(
    typing_extensions.TypedDict, total=False
):
    text: str

@typing.type_check_only
class GoogleCloudDatacatalogV1PolicyTag(typing_extensions.TypedDict, total=False):
    childPolicyTags: _list[str]
    description: str
    displayName: str
    name: str
    parentPolicyTag: str

@typing.type_check_only
class GoogleCloudDatacatalogV1RenameTagTemplateFieldEnumValueRequest(
    typing_extensions.TypedDict, total=False
):
    newEnumValueDisplayName: str

@typing.type_check_only
class GoogleCloudDatacatalogV1RenameTagTemplateFieldRequest(
    typing_extensions.TypedDict, total=False
):
    newTagTemplateFieldId: str

@typing.type_check_only
class GoogleCloudDatacatalogV1ReplaceTaxonomyRequest(
    typing_extensions.TypedDict, total=False
):
    serializedTaxonomy: GoogleCloudDatacatalogV1SerializedTaxonomy

@typing.type_check_only
class GoogleCloudDatacatalogV1RoutineSpec(typing_extensions.TypedDict, total=False):
    bigqueryRoutineSpec: GoogleCloudDatacatalogV1BigQueryRoutineSpec
    definitionBody: str
    language: str
    returnType: str
    routineArguments: _list[GoogleCloudDatacatalogV1RoutineSpecArgument]
    routineType: typing_extensions.Literal[
        "ROUTINE_TYPE_UNSPECIFIED", "SCALAR_FUNCTION", "PROCEDURE"
    ]

@typing.type_check_only
class GoogleCloudDatacatalogV1RoutineSpecArgument(
    typing_extensions.TypedDict, total=False
):
    mode: typing_extensions.Literal["MODE_UNSPECIFIED", "IN", "OUT", "INOUT"]
    name: str
    type: str

@typing.type_check_only
class GoogleCloudDatacatalogV1Schema(typing_extensions.TypedDict, total=False):
    columns: _list[GoogleCloudDatacatalogV1ColumnSchema]

@typing.type_check_only
class GoogleCloudDatacatalogV1SearchCatalogRequest(
    typing_extensions.TypedDict, total=False
):
    orderBy: str
    pageSize: int
    pageToken: str
    query: str
    scope: GoogleCloudDatacatalogV1SearchCatalogRequestScope

@typing.type_check_only
class GoogleCloudDatacatalogV1SearchCatalogRequestScope(
    typing_extensions.TypedDict, total=False
):
    includeGcpPublicDatasets: bool
    includeOrgIds: _list[str]
    includeProjectIds: _list[str]
    includePublicTagTemplates: bool
    restrictedLocations: _list[str]
    starredOnly: bool

@typing.type_check_only
class GoogleCloudDatacatalogV1SearchCatalogResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    results: _list[GoogleCloudDatacatalogV1SearchCatalogResult]
    unreachable: _list[str]

@typing.type_check_only
class GoogleCloudDatacatalogV1SearchCatalogResult(
    typing_extensions.TypedDict, total=False
):
    description: str
    displayName: str
    fullyQualifiedName: str
    integratedSystem: typing_extensions.Literal[
        "INTEGRATED_SYSTEM_UNSPECIFIED",
        "BIGQUERY",
        "CLOUD_PUBSUB",
        "DATAPROC_METASTORE",
        "DATAPLEX",
    ]
    linkedResource: str
    modifyTime: str
    relativeResourceName: str
    searchResultSubtype: str
    searchResultType: typing_extensions.Literal[
        "SEARCH_RESULT_TYPE_UNSPECIFIED", "ENTRY", "TAG_TEMPLATE", "ENTRY_GROUP"
    ]
    userSpecifiedSystem: str

@typing.type_check_only
class GoogleCloudDatacatalogV1SerializedPolicyTag(
    typing_extensions.TypedDict, total=False
):
    childPolicyTags: _list[GoogleCloudDatacatalogV1SerializedPolicyTag]
    description: str
    displayName: str
    policyTag: str

@typing.type_check_only
class GoogleCloudDatacatalogV1SerializedTaxonomy(
    typing_extensions.TypedDict, total=False
):
    activatedPolicyTypes: _list[str]
    description: str
    displayName: str
    policyTags: _list[GoogleCloudDatacatalogV1SerializedPolicyTag]

@typing.type_check_only
class GoogleCloudDatacatalogV1StarEntryRequest(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudDatacatalogV1StarEntryResponse(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudDatacatalogV1StorageProperties(
    typing_extensions.TypedDict, total=False
):
    filePattern: _list[str]
    fileType: str

@typing.type_check_only
class GoogleCloudDatacatalogV1SystemTimestamps(
    typing_extensions.TypedDict, total=False
):
    createTime: str
    expireTime: str
    updateTime: str

@typing.type_check_only
class GoogleCloudDatacatalogV1TableSpec(typing_extensions.TypedDict, total=False):
    groupedEntry: str

@typing.type_check_only
class GoogleCloudDatacatalogV1Tag(typing_extensions.TypedDict, total=False):
    column: str
    fields: dict[str, typing.Any]
    name: str
    template: str
    templateDisplayName: str

@typing.type_check_only
class GoogleCloudDatacatalogV1TagField(typing_extensions.TypedDict, total=False):
    boolValue: bool
    displayName: str
    doubleValue: float
    enumValue: GoogleCloudDatacatalogV1TagFieldEnumValue
    order: int
    richtextValue: str
    stringValue: str
    timestampValue: str

@typing.type_check_only
class GoogleCloudDatacatalogV1TagFieldEnumValue(
    typing_extensions.TypedDict, total=False
):
    displayName: str

@typing.type_check_only
class GoogleCloudDatacatalogV1TagTemplate(typing_extensions.TypedDict, total=False):
    displayName: str
    fields: dict[str, typing.Any]
    isPubliclyReadable: bool
    name: str

@typing.type_check_only
class GoogleCloudDatacatalogV1TagTemplateField(
    typing_extensions.TypedDict, total=False
):
    description: str
    displayName: str
    isRequired: bool
    name: str
    order: int
    type: GoogleCloudDatacatalogV1FieldType

@typing.type_check_only
class GoogleCloudDatacatalogV1Taxonomy(typing_extensions.TypedDict, total=False):
    activatedPolicyTypes: _list[str]
    description: str
    displayName: str
    name: str
    policyTagCount: int
    taxonomyTimestamps: GoogleCloudDatacatalogV1SystemTimestamps

@typing.type_check_only
class GoogleCloudDatacatalogV1UnstarEntryRequest(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudDatacatalogV1UnstarEntryResponse(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleCloudDatacatalogV1UsageSignal(typing_extensions.TypedDict, total=False):
    favoriteCount: str
    updateTime: str
    usageWithinTimeRange: dict[str, typing.Any]

@typing.type_check_only
class GoogleCloudDatacatalogV1UsageStats(typing_extensions.TypedDict, total=False):
    totalCancellations: float
    totalCompletions: float
    totalExecutionTimeForCompletionsMillis: float
    totalFailures: float

@typing.type_check_only
class GoogleCloudDatacatalogV1ViewSpec(typing_extensions.TypedDict, total=False):
    viewQuery: str

@typing.type_check_only
class Policy(typing_extensions.TypedDict, total=False):
    bindings: _list[Binding]
    etag: str
    version: int

@typing.type_check_only
class SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: Policy

@typing.type_check_only
class TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class ChromePolicyResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class CustomersResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class PoliciesResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class GroupsResource(googleapiclient.discovery.Resource):
                def batchDelete(
                    self,
                    *,
                    customer: str,
                    body: GoogleChromePolicyV1BatchDeleteGroupPoliciesRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def batchModify(
                    self,
                    *,
                    customer: str,
                    body: GoogleChromePolicyV1BatchModifyGroupPoliciesRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def listGroupPriorityOrdering(
                    self,
                    *,
                    customer: str,
                    body: GoogleChromePolicyV1ListGroupPriorityOrderingRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleChromePolicyV1ListGroupPriorityOrderingResponseHttpRequest: ...
                def updateGroupPriorityOrdering(
                    self,
                    *,
                    customer: str,
                    body: GoogleChromePolicyV1UpdateGroupPriorityOrderingRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...

            @typing.type_check_only
            class NetworksResource(googleapiclient.discovery.Resource):
                def defineCertificate(
                    self,
                    *,
                    customer: str,
                    body: GoogleChromePolicyV1DefineCertificateRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleChromePolicyV1DefineCertificateResponseHttpRequest: ...
                def defineNetwork(
                    self,
                    *,
                    customer: str,
                    body: GoogleChromePolicyV1DefineNetworkRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleChromePolicyV1DefineNetworkResponseHttpRequest: ...
                def removeCertificate(
                    self,
                    *,
                    customer: str,
                    body: GoogleChromePolicyV1RemoveCertificateRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleChromePolicyV1RemoveCertificateResponseHttpRequest: ...
                def removeNetwork(
                    self,
                    *,
                    customer: str,
                    body: GoogleChromePolicyV1RemoveNetworkRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleChromePolicyV1RemoveNetworkResponseHttpRequest: ...

            @typing.type_check_only
            class OrgunitsResource(googleapiclient.discovery.Resource):
                def batchInherit(
                    self,
                    *,
                    customer: str,
                    body: GoogleChromePolicyV1BatchInheritOrgUnitPoliciesRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...
                def batchModify(
                    self,
                    *,
                    customer: str,
                    body: GoogleChromePolicyV1BatchModifyOrgUnitPoliciesRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleProtobufEmptyHttpRequest: ...

            def resolve(
                self,
                *,
                customer: str,
                body: GoogleChromePolicyV1ResolveRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleChromePolicyV1ResolveResponseHttpRequest: ...
            def resolve_next(
                self,
                previous_request: GoogleChromePolicyV1ResolveResponseHttpRequest,
                previous_response: GoogleChromePolicyV1ResolveResponse,
            ) -> GoogleChromePolicyV1ResolveResponseHttpRequest | None: ...
            def groups(self) -> GroupsResource: ...
            def networks(self) -> NetworksResource: ...
            def orgunits(self) -> OrgunitsResource: ...

        @typing.type_check_only
        class PolicySchemasResource(googleapiclient.discovery.Resource):
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleChromePolicyVersionsV1PolicySchemaHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleChromePolicyVersionsV1ListPolicySchemasResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleChromePolicyVersionsV1ListPolicySchemasResponseHttpRequest,
                previous_response: GoogleChromePolicyVersionsV1ListPolicySchemasResponse,
            ) -> GoogleChromePolicyVersionsV1ListPolicySchemasResponseHttpRequest | None: ...

        def policies(self) -> PoliciesResource: ...
        def policySchemas(self) -> PolicySchemasResource: ...

    @typing.type_check_only
    class MediaResource(googleapiclient.discovery.Resource):
        def upload(
            self,
            *,
            customer: str,
            body: GoogleChromePolicyVersionsV1UploadPolicyFileRequest = ...,
            **kwargs: typing.Any
        ) -> GoogleChromePolicyVersionsV1UploadPolicyFileResponseHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def customers(self) -> CustomersResource: ...
    def media(self) -> MediaResource: ...

@typing.type_check_only
class GoogleChromePolicyV1DefineCertificateResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleChromePolicyV1DefineCertificateResponse: ...

@typing.type_check_only
class GoogleChromePolicyV1DefineNetworkResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleChromePolicyV1DefineNetworkResponse: ...

@typing.type_check_only
class GoogleChromePolicyV1ListGroupPriorityOrderingResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleChromePolicyV1ListGroupPriorityOrderingResponse: ...

@typing.type_check_only
class GoogleChromePolicyV1RemoveCertificateResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleChromePolicyV1RemoveCertificateResponse: ...

@typing.type_check_only
class GoogleChromePolicyV1RemoveNetworkResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleChromePolicyV1RemoveNetworkResponse: ...

@typing.type_check_only
class GoogleChromePolicyV1ResolveResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleChromePolicyV1ResolveResponse: ...

@typing.type_check_only
class GoogleChromePolicyVersionsV1ListPolicySchemasResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleChromePolicyVersionsV1ListPolicySchemasResponse: ...

@typing.type_check_only
class GoogleChromePolicyVersionsV1PolicySchemaHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleChromePolicyVersionsV1PolicySchema: ...

@typing.type_check_only
class GoogleChromePolicyVersionsV1UploadPolicyFileResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleChromePolicyVersionsV1UploadPolicyFileResponse: ...

@typing.type_check_only
class GoogleProtobufEmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleProtobufEmpty: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class AdMobResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AccountsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class AdUnitsResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListAdUnitsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListAdUnitsResponseHttpRequest,
                previous_response: ListAdUnitsResponse,
            ) -> ListAdUnitsResponseHttpRequest | None: ...

        @typing.type_check_only
        class AppsResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListAppsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListAppsResponseHttpRequest,
                previous_response: ListAppsResponse,
            ) -> ListAppsResponseHttpRequest | None: ...

        @typing.type_check_only
        class MediationReportResource(googleapiclient.discovery.Resource):
            def generate(
                self,
                *,
                parent: str,
                body: GenerateMediationReportRequest = ...,
                **kwargs: typing.Any
            ) -> GenerateMediationReportResponseHttpRequest: ...

        @typing.type_check_only
        class NetworkReportResource(googleapiclient.discovery.Resource):
            def generate(
                self,
                *,
                parent: str,
                body: GenerateNetworkReportRequest = ...,
                **kwargs: typing.Any
            ) -> GenerateNetworkReportResponseHttpRequest: ...

        def get(
            self, *, name: str, **kwargs: typing.Any
        ) -> PublisherAccountHttpRequest: ...
        def list(
            self, *, pageSize: int = ..., pageToken: str = ..., **kwargs: typing.Any
        ) -> ListPublisherAccountsResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListPublisherAccountsResponseHttpRequest,
            previous_response: ListPublisherAccountsResponse,
        ) -> ListPublisherAccountsResponseHttpRequest | None: ...
        def adUnits(self) -> AdUnitsResource: ...
        def apps(self) -> AppsResource: ...
        def mediationReport(self) -> MediationReportResource: ...
        def networkReport(self) -> NetworkReportResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def accounts(self) -> AccountsResource: ...

@typing.type_check_only
class GenerateMediationReportResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GenerateMediationReportResponse: ...

@typing.type_check_only
class GenerateNetworkReportResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GenerateNetworkReportResponse: ...

@typing.type_check_only
class ListAdUnitsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAdUnitsResponse: ...

@typing.type_check_only
class ListAppsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAppsResponse: ...

@typing.type_check_only
class ListPublisherAccountsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListPublisherAccountsResponse: ...

@typing.type_check_only
class PublisherAccountHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PublisherAccount: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class CloudSearchResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class DebugResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class DatasourcesResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class ItemsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class UnmappedidsResource(googleapiclient.discovery.Resource):
                    def list(
                        self,
                        *,
                        parent: str,
                        debugOptions_enableDebugging: bool = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListUnmappedIdentitiesResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListUnmappedIdentitiesResponseHttpRequest,
                        previous_response: ListUnmappedIdentitiesResponse,
                    ) -> ListUnmappedIdentitiesResponseHttpRequest | None: ...

                def checkAccess(
                    self,
                    *,
                    name: str,
                    body: Principal = ...,
                    debugOptions_enableDebugging: bool = ...,
                    **kwargs: typing.Any
                ) -> CheckAccessResponseHttpRequest: ...
                def searchByViewUrl(
                    self,
                    *,
                    name: str,
                    body: SearchItemsByViewUrlRequest = ...,
                    **kwargs: typing.Any
                ) -> SearchItemsByViewUrlResponseHttpRequest: ...
                def searchByViewUrl_next(
                    self,
                    previous_request: SearchItemsByViewUrlResponseHttpRequest,
                    previous_response: SearchItemsByViewUrlResponse,
                ) -> SearchItemsByViewUrlResponseHttpRequest | None: ...
                def unmappedids(self) -> UnmappedidsResource: ...

            def items(self) -> ItemsResource: ...

        @typing.type_check_only
        class IdentitysourcesResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class ItemsResource(googleapiclient.discovery.Resource):
                def listForunmappedidentity(
                    self,
                    *,
                    parent: str,
                    debugOptions_enableDebugging: bool = ...,
                    groupResourceName: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    userResourceName: str = ...,
                    **kwargs: typing.Any
                ) -> ListItemNamesForUnmappedIdentityResponseHttpRequest: ...
                def listForunmappedidentity_next(
                    self,
                    previous_request: ListItemNamesForUnmappedIdentityResponseHttpRequest,
                    previous_response: ListItemNamesForUnmappedIdentityResponse,
                ) -> ListItemNamesForUnmappedIdentityResponseHttpRequest | None: ...

            @typing.type_check_only
            class UnmappedidsResource(googleapiclient.discovery.Resource):
                def list(
                    self,
                    *,
                    parent: str,
                    debugOptions_enableDebugging: bool = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    resolutionStatusCode: typing_extensions.Literal[
                        "CODE_UNSPECIFIED",
                        "NOT_FOUND",
                        "IDENTITY_SOURCE_NOT_FOUND",
                        "IDENTITY_SOURCE_MISCONFIGURED",
                        "TOO_MANY_MAPPINGS_FOUND",
                        "INTERNAL_ERROR",
                    ] = ...,
                    **kwargs: typing.Any
                ) -> ListUnmappedIdentitiesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListUnmappedIdentitiesResponseHttpRequest,
                    previous_response: ListUnmappedIdentitiesResponse,
                ) -> ListUnmappedIdentitiesResponseHttpRequest | None: ...

            def items(self) -> ItemsResource: ...
            def unmappedids(self) -> UnmappedidsResource: ...

        def datasources(self) -> DatasourcesResource: ...
        def identitysources(self) -> IdentitysourcesResource: ...

    @typing.type_check_only
    class IndexingResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class DatasourcesResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class ItemsResource(googleapiclient.discovery.Resource):
                def delete(
                    self,
                    *,
                    name: str,
                    connectorName: str = ...,
                    debugOptions_enableDebugging: bool = ...,
                    mode: typing_extensions.Literal[
                        "UNSPECIFIED", "SYNCHRONOUS", "ASYNCHRONOUS"
                    ] = ...,
                    version: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def deleteQueueItems(
                    self,
                    *,
                    name: str,
                    body: DeleteQueueItemsRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self,
                    *,
                    name: str,
                    connectorName: str = ...,
                    debugOptions_enableDebugging: bool = ...,
                    **kwargs: typing.Any
                ) -> ItemHttpRequest: ...
                def index(
                    self,
                    *,
                    name: str,
                    body: IndexItemRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def list(
                    self,
                    *,
                    name: str,
                    brief: bool = ...,
                    connectorName: str = ...,
                    debugOptions_enableDebugging: bool = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListItemsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListItemsResponseHttpRequest,
                    previous_response: ListItemsResponse,
                ) -> ListItemsResponseHttpRequest | None: ...
                def poll(
                    self,
                    *,
                    name: str,
                    body: PollItemsRequest = ...,
                    **kwargs: typing.Any
                ) -> PollItemsResponseHttpRequest: ...
                def push(
                    self,
                    *,
                    name: str,
                    body: PushItemRequest = ...,
                    **kwargs: typing.Any
                ) -> ItemHttpRequest: ...
                def unreserve(
                    self,
                    *,
                    name: str,
                    body: UnreserveItemsRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def upload(
                    self,
                    *,
                    name: str,
                    body: StartUploadItemRequest = ...,
                    **kwargs: typing.Any
                ) -> UploadItemRefHttpRequest: ...

            def deleteSchema(
                self,
                *,
                name: str,
                debugOptions_enableDebugging: bool = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def getSchema(
                self,
                *,
                name: str,
                debugOptions_enableDebugging: bool = ...,
                **kwargs: typing.Any
            ) -> SchemaHttpRequest: ...
            def updateSchema(
                self,
                *,
                name: str,
                body: UpdateSchemaRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def items(self) -> ItemsResource: ...

        def datasources(self) -> DatasourcesResource: ...

    @typing.type_check_only
    class MediaResource(googleapiclient.discovery.Resource):
        def upload(
            self, *, resourceName: str, body: Media = ..., **kwargs: typing.Any
        ) -> MediaHttpRequest: ...

    @typing.type_check_only
    class OperationsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LroResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                name: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListOperationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListOperationsResponseHttpRequest,
                previous_response: ListOperationsResponse,
            ) -> ListOperationsResponseHttpRequest | None: ...

        def get(self, *, name: str, **kwargs: typing.Any) -> OperationHttpRequest: ...
        def lro(self) -> LroResource: ...

    @typing.type_check_only
    class QueryResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class SourcesResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                pageToken: str = ...,
                requestOptions_debugOptions_enableDebugging: bool = ...,
                requestOptions_languageCode: str = ...,
                requestOptions_searchApplicationId: str = ...,
                requestOptions_timeZone: str = ...,
                **kwargs: typing.Any
            ) -> ListQuerySourcesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListQuerySourcesResponseHttpRequest,
                previous_response: ListQuerySourcesResponse,
            ) -> ListQuerySourcesResponseHttpRequest | None: ...

        def search(
            self, *, body: SearchRequest = ..., **kwargs: typing.Any
        ) -> SearchResponseHttpRequest: ...
        def suggest(
            self, *, body: SuggestRequest = ..., **kwargs: typing.Any
        ) -> SuggestResponseHttpRequest: ...
        def sources(self) -> SourcesResource: ...

    @typing.type_check_only
    class SettingsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class DatasourcesResource(googleapiclient.discovery.Resource):
            def create(
                self, *, body: DataSource = ..., **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def delete(
                self,
                *,
                name: str,
                debugOptions_enableDebugging: bool = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def get(
                self,
                *,
                name: str,
                debugOptions_enableDebugging: bool = ...,
                **kwargs: typing.Any
            ) -> DataSourceHttpRequest: ...
            def list(
                self,
                *,
                debugOptions_enableDebugging: bool = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListDataSourceResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListDataSourceResponseHttpRequest,
                previous_response: ListDataSourceResponse,
            ) -> ListDataSourceResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: DataSource = ...,
                debugOptions_enableDebugging: bool = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def update(
                self,
                *,
                name: str,
                body: UpdateDataSourceRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...

        @typing.type_check_only
        class SearchapplicationsResource(googleapiclient.discovery.Resource):
            def create(
                self, *, body: SearchApplication = ..., **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def delete(
                self,
                *,
                name: str,
                debugOptions_enableDebugging: bool = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def get(
                self,
                *,
                name: str,
                debugOptions_enableDebugging: bool = ...,
                **kwargs: typing.Any
            ) -> SearchApplicationHttpRequest: ...
            def list(
                self,
                *,
                debugOptions_enableDebugging: bool = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListSearchApplicationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListSearchApplicationsResponseHttpRequest,
                previous_response: ListSearchApplicationsResponse,
            ) -> ListSearchApplicationsResponseHttpRequest | None: ...
            def patch(
                self, *, name: str, body: SearchApplication = ..., **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def reset(
                self,
                *,
                name: str,
                body: ResetSearchApplicationRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def update(
                self, *, name: str, body: SearchApplication = ..., **kwargs: typing.Any
            ) -> OperationHttpRequest: ...

        def getCustomer(self, **kwargs: typing.Any) -> CustomerSettingsHttpRequest: ...
        def updateCustomer(
            self,
            *,
            body: CustomerSettings = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def datasources(self) -> DatasourcesResource: ...
        def searchapplications(self) -> SearchapplicationsResource: ...

    @typing.type_check_only
    class StatsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class IndexResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class DatasourcesResource(googleapiclient.discovery.Resource):
                def get(
                    self,
                    *,
                    name: str,
                    fromDate_day: int = ...,
                    fromDate_month: int = ...,
                    fromDate_year: int = ...,
                    toDate_day: int = ...,
                    toDate_month: int = ...,
                    toDate_year: int = ...,
                    **kwargs: typing.Any
                ) -> GetDataSourceIndexStatsResponseHttpRequest: ...

            def datasources(self) -> DatasourcesResource: ...

        @typing.type_check_only
        class QueryResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class SearchapplicationsResource(googleapiclient.discovery.Resource):
                def get(
                    self,
                    *,
                    name: str,
                    fromDate_day: int = ...,
                    fromDate_month: int = ...,
                    fromDate_year: int = ...,
                    toDate_day: int = ...,
                    toDate_month: int = ...,
                    toDate_year: int = ...,
                    **kwargs: typing.Any
                ) -> GetSearchApplicationQueryStatsResponseHttpRequest: ...

            def searchapplications(self) -> SearchapplicationsResource: ...

        @typing.type_check_only
        class SessionResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class SearchapplicationsResource(googleapiclient.discovery.Resource):
                def get(
                    self,
                    *,
                    name: str,
                    fromDate_day: int = ...,
                    fromDate_month: int = ...,
                    fromDate_year: int = ...,
                    toDate_day: int = ...,
                    toDate_month: int = ...,
                    toDate_year: int = ...,
                    **kwargs: typing.Any
                ) -> GetSearchApplicationSessionStatsResponseHttpRequest: ...

            def searchapplications(self) -> SearchapplicationsResource: ...

        @typing.type_check_only
        class UserResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class SearchapplicationsResource(googleapiclient.discovery.Resource):
                def get(
                    self,
                    *,
                    name: str,
                    fromDate_day: int = ...,
                    fromDate_month: int = ...,
                    fromDate_year: int = ...,
                    toDate_day: int = ...,
                    toDate_month: int = ...,
                    toDate_year: int = ...,
                    **kwargs: typing.Any
                ) -> GetSearchApplicationUserStatsResponseHttpRequest: ...

            def searchapplications(self) -> SearchapplicationsResource: ...

        def getIndex(
            self,
            *,
            fromDate_day: int = ...,
            fromDate_month: int = ...,
            fromDate_year: int = ...,
            toDate_day: int = ...,
            toDate_month: int = ...,
            toDate_year: int = ...,
            **kwargs: typing.Any
        ) -> GetCustomerIndexStatsResponseHttpRequest: ...
        def getQuery(
            self,
            *,
            fromDate_day: int = ...,
            fromDate_month: int = ...,
            fromDate_year: int = ...,
            toDate_day: int = ...,
            toDate_month: int = ...,
            toDate_year: int = ...,
            **kwargs: typing.Any
        ) -> GetCustomerQueryStatsResponseHttpRequest: ...
        def getSearchapplication(
            self,
            *,
            endDate_day: int = ...,
            endDate_month: int = ...,
            endDate_year: int = ...,
            startDate_day: int = ...,
            startDate_month: int = ...,
            startDate_year: int = ...,
            **kwargs: typing.Any
        ) -> GetCustomerSearchApplicationStatsResponseHttpRequest: ...
        def getSession(
            self,
            *,
            fromDate_day: int = ...,
            fromDate_month: int = ...,
            fromDate_year: int = ...,
            toDate_day: int = ...,
            toDate_month: int = ...,
            toDate_year: int = ...,
            **kwargs: typing.Any
        ) -> GetCustomerSessionStatsResponseHttpRequest: ...
        def getUser(
            self,
            *,
            fromDate_day: int = ...,
            fromDate_month: int = ...,
            fromDate_year: int = ...,
            toDate_day: int = ...,
            toDate_month: int = ...,
            toDate_year: int = ...,
            **kwargs: typing.Any
        ) -> GetCustomerUserStatsResponseHttpRequest: ...
        def index(self) -> IndexResource: ...
        def query(self) -> QueryResource: ...
        def session(self) -> SessionResource: ...
        def user(self) -> UserResource: ...

    @typing.type_check_only
    class V1Resource(googleapiclient.discovery.Resource):
        def initializeCustomer(
            self, *, body: InitializeCustomerRequest = ..., **kwargs: typing.Any
        ) -> OperationHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def debug(self) -> DebugResource: ...
    def indexing(self) -> IndexingResource: ...
    def media(self) -> MediaResource: ...
    def operations(self) -> OperationsResource: ...
    def query(self) -> QueryResource: ...
    def settings(self) -> SettingsResource: ...
    def stats(self) -> StatsResource: ...
    def v1(self) -> V1Resource: ...

@typing.type_check_only
class CheckAccessResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CheckAccessResponse: ...

@typing.type_check_only
class CustomerSettingsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CustomerSettings: ...

@typing.type_check_only
class DataSourceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DataSource: ...

@typing.type_check_only
class GetCustomerIndexStatsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GetCustomerIndexStatsResponse: ...

@typing.type_check_only
class GetCustomerQueryStatsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GetCustomerQueryStatsResponse: ...

@typing.type_check_only
class GetCustomerSearchApplicationStatsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GetCustomerSearchApplicationStatsResponse: ...

@typing.type_check_only
class GetCustomerSessionStatsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GetCustomerSessionStatsResponse: ...

@typing.type_check_only
class GetCustomerUserStatsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GetCustomerUserStatsResponse: ...

@typing.type_check_only
class GetDataSourceIndexStatsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GetDataSourceIndexStatsResponse: ...

@typing.type_check_only
class GetSearchApplicationQueryStatsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GetSearchApplicationQueryStatsResponse: ...

@typing.type_check_only
class GetSearchApplicationSessionStatsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GetSearchApplicationSessionStatsResponse: ...

@typing.type_check_only
class GetSearchApplicationUserStatsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GetSearchApplicationUserStatsResponse: ...

@typing.type_check_only
class ItemHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Item: ...

@typing.type_check_only
class ListDataSourceResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListDataSourceResponse: ...

@typing.type_check_only
class ListItemNamesForUnmappedIdentityResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListItemNamesForUnmappedIdentityResponse: ...

@typing.type_check_only
class ListItemsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListItemsResponse: ...

@typing.type_check_only
class ListOperationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListOperationsResponse: ...

@typing.type_check_only
class ListQuerySourcesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListQuerySourcesResponse: ...

@typing.type_check_only
class ListSearchApplicationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListSearchApplicationsResponse: ...

@typing.type_check_only
class ListUnmappedIdentitiesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListUnmappedIdentitiesResponse: ...

@typing.type_check_only
class MediaHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Media: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class PollItemsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PollItemsResponse: ...

@typing.type_check_only
class SchemaHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Schema: ...

@typing.type_check_only
class SearchApplicationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SearchApplication: ...

@typing.type_check_only
class SearchItemsByViewUrlResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SearchItemsByViewUrlResponse: ...

@typing.type_check_only
class SearchResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SearchResponse: ...

@typing.type_check_only
class SuggestResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SuggestResponse: ...

@typing.type_check_only
class UploadItemRefHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> UploadItemRef: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class CloudMachineLearningEngineResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class JobsResource(googleapiclient.discovery.Resource):
            def cancel(
                self,
                *,
                name: str,
                body: GoogleCloudMlV1__CancelJobRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleProtobuf__EmptyHttpRequest: ...
            def create(
                self,
                *,
                parent: str,
                body: GoogleCloudMlV1__Job = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudMlV1__JobHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleCloudMlV1__JobHttpRequest: ...
            def getIamPolicy(
                self,
                *,
                resource: str,
                options_requestedPolicyVersion: int = ...,
                **kwargs: typing.Any
            ) -> GoogleIamV1__PolicyHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudMlV1__ListJobsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleCloudMlV1__ListJobsResponseHttpRequest,
                previous_response: GoogleCloudMlV1__ListJobsResponse,
            ) -> GoogleCloudMlV1__ListJobsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GoogleCloudMlV1__Job = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudMlV1__JobHttpRequest: ...
            def setIamPolicy(
                self,
                *,
                resource: str,
                body: GoogleIamV1__SetIamPolicyRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleIamV1__PolicyHttpRequest: ...
            def testIamPermissions(
                self,
                *,
                resource: str,
                body: GoogleIamV1__TestIamPermissionsRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleIamV1__TestIamPermissionsResponseHttpRequest: ...

        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def cancel(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleProtobuf__EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleLongrunning__OperationHttpRequest: ...

            @typing.type_check_only
            class StudiesResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class TrialsResource(googleapiclient.discovery.Resource):
                    def addMeasurement(
                        self,
                        *,
                        name: str,
                        body: GoogleCloudMlV1__AddTrialMeasurementRequest = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudMlV1__TrialHttpRequest: ...
                    def checkEarlyStoppingState(
                        self,
                        *,
                        name: str,
                        body: GoogleCloudMlV1__CheckTrialEarlyStoppingStateRequest = ...,
                        **kwargs: typing.Any
                    ) -> GoogleLongrunning__OperationHttpRequest: ...
                    def complete(
                        self,
                        *,
                        name: str,
                        body: GoogleCloudMlV1__CompleteTrialRequest = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudMlV1__TrialHttpRequest: ...
                    def create(
                        self,
                        *,
                        parent: str,
                        body: GoogleCloudMlV1__Trial = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudMlV1__TrialHttpRequest: ...
                    def delete(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> GoogleProtobuf__EmptyHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> GoogleCloudMlV1__TrialHttpRequest: ...
                    def list(
                        self, *, parent: str, **kwargs: typing.Any
                    ) -> GoogleCloudMlV1__ListTrialsResponseHttpRequest: ...
                    def listOptimalTrials(
                        self,
                        *,
                        parent: str,
                        body: GoogleCloudMlV1__ListOptimalTrialsRequest = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudMlV1__ListOptimalTrialsResponseHttpRequest: ...
                    def stop(
                        self,
                        *,
                        name: str,
                        body: GoogleCloudMlV1__StopTrialRequest = ...,
                        **kwargs: typing.Any
                    ) -> GoogleCloudMlV1__TrialHttpRequest: ...
                    def suggest(
                        self,
                        *,
                        parent: str,
                        body: GoogleCloudMlV1__SuggestTrialsRequest = ...,
                        **kwargs: typing.Any
                    ) -> GoogleLongrunning__OperationHttpRequest: ...

                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudMlV1__Study = ...,
                    studyId: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudMlV1__StudyHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleProtobuf__EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleCloudMlV1__StudyHttpRequest: ...
                def list(
                    self, *, parent: str, **kwargs: typing.Any
                ) -> GoogleCloudMlV1__ListStudiesResponseHttpRequest: ...
                def trials(self) -> TrialsResource: ...

            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleCloudMlV1__LocationHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudMlV1__ListLocationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleCloudMlV1__ListLocationsResponseHttpRequest,
                previous_response: GoogleCloudMlV1__ListLocationsResponse,
            ) -> GoogleCloudMlV1__ListLocationsResponseHttpRequest | None: ...
            def operations(self) -> OperationsResource: ...
            def studies(self) -> StudiesResource: ...

        @typing.type_check_only
        class ModelsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class VersionsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleCloudMlV1__Version = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunning__OperationHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleLongrunning__OperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleCloudMlV1__VersionHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudMlV1__ListVersionsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: GoogleCloudMlV1__ListVersionsResponseHttpRequest,
                    previous_response: GoogleCloudMlV1__ListVersionsResponse,
                ) -> GoogleCloudMlV1__ListVersionsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudMlV1__Version = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunning__OperationHttpRequest: ...
                def setDefault(
                    self,
                    *,
                    name: str,
                    body: GoogleCloudMlV1__SetDefaultVersionRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleCloudMlV1__VersionHttpRequest: ...

            def create(
                self,
                *,
                parent: str,
                body: GoogleCloudMlV1__Model = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudMlV1__ModelHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleLongrunning__OperationHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleCloudMlV1__ModelHttpRequest: ...
            def getIamPolicy(
                self,
                *,
                resource: str,
                options_requestedPolicyVersion: int = ...,
                **kwargs: typing.Any
            ) -> GoogleIamV1__PolicyHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudMlV1__ListModelsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleCloudMlV1__ListModelsResponseHttpRequest,
                previous_response: GoogleCloudMlV1__ListModelsResponse,
            ) -> GoogleCloudMlV1__ListModelsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GoogleCloudMlV1__Model = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> GoogleLongrunning__OperationHttpRequest: ...
            def setIamPolicy(
                self,
                *,
                resource: str,
                body: GoogleIamV1__SetIamPolicyRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleIamV1__PolicyHttpRequest: ...
            def testIamPermissions(
                self,
                *,
                resource: str,
                body: GoogleIamV1__TestIamPermissionsRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleIamV1__TestIamPermissionsResponseHttpRequest: ...
            def versions(self) -> VersionsResource: ...

        @typing.type_check_only
        class OperationsResource(googleapiclient.discovery.Resource):
            def cancel(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleProtobuf__EmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleLongrunning__OperationHttpRequest: ...
            def list(
                self,
                *,
                name: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleLongrunning__ListOperationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleLongrunning__ListOperationsResponseHttpRequest,
                previous_response: GoogleLongrunning__ListOperationsResponse,
            ) -> GoogleLongrunning__ListOperationsResponseHttpRequest | None: ...

        def explain(
            self,
            *,
            name: str,
            body: GoogleCloudMlV1__ExplainRequest = ...,
            **kwargs: typing.Any
        ) -> GoogleApi__HttpBodyHttpRequest: ...
        def getConfig(
            self, *, name: str, **kwargs: typing.Any
        ) -> GoogleCloudMlV1__GetConfigResponseHttpRequest: ...
        def predict(
            self,
            *,
            name: str,
            body: GoogleCloudMlV1__PredictRequest = ...,
            **kwargs: typing.Any
        ) -> GoogleApi__HttpBodyHttpRequest: ...
        def jobs(self) -> JobsResource: ...
        def locations(self) -> LocationsResource: ...
        def models(self) -> ModelsResource: ...
        def operations(self) -> OperationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class GoogleApi__HttpBodyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleApi__HttpBody: ...

@typing.type_check_only
class GoogleCloudMlV1__GetConfigResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudMlV1__GetConfigResponse: ...

@typing.type_check_only
class GoogleCloudMlV1__JobHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudMlV1__Job: ...

@typing.type_check_only
class GoogleCloudMlV1__ListJobsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudMlV1__ListJobsResponse: ...

@typing.type_check_only
class GoogleCloudMlV1__ListLocationsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudMlV1__ListLocationsResponse: ...

@typing.type_check_only
class GoogleCloudMlV1__ListModelsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudMlV1__ListModelsResponse: ...

@typing.type_check_only
class GoogleCloudMlV1__ListOptimalTrialsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudMlV1__ListOptimalTrialsResponse: ...

@typing.type_check_only
class GoogleCloudMlV1__ListStudiesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudMlV1__ListStudiesResponse: ...

@typing.type_check_only
class GoogleCloudMlV1__ListTrialsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudMlV1__ListTrialsResponse: ...

@typing.type_check_only
class GoogleCloudMlV1__ListVersionsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudMlV1__ListVersionsResponse: ...

@typing.type_check_only
class GoogleCloudMlV1__LocationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudMlV1__Location: ...

@typing.type_check_only
class GoogleCloudMlV1__ModelHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudMlV1__Model: ...

@typing.type_check_only
class GoogleCloudMlV1__StudyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudMlV1__Study: ...

@typing.type_check_only
class GoogleCloudMlV1__TrialHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudMlV1__Trial: ...

@typing.type_check_only
class GoogleCloudMlV1__VersionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudMlV1__Version: ...

@typing.type_check_only
class GoogleIamV1__PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleIamV1__Policy: ...

@typing.type_check_only
class GoogleIamV1__TestIamPermissionsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleIamV1__TestIamPermissionsResponse: ...

@typing.type_check_only
class GoogleLongrunning__ListOperationsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleLongrunning__ListOperationsResponse: ...

@typing.type_check_only
class GoogleLongrunning__OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleLongrunning__Operation: ...

@typing.type_check_only
class GoogleProtobuf__EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleProtobuf__Empty: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Attachment(typing_extensions.TypedDict, total=False):
    mimeType: _list[str]
    name: str

@typing.type_check_only
class BatchCreatePermissionsRequest(typing_extensions.TypedDict, total=False):
    requests: _list[CreatePermissionRequest]

@typing.type_check_only
class BatchCreatePermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[Permission]

@typing.type_check_only
class BatchDeletePermissionsRequest(typing_extensions.TypedDict, total=False):
    names: _list[str]

@typing.type_check_only
class CreatePermissionRequest(typing_extensions.TypedDict, total=False):
    parent: str
    permission: Permission

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Family(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Group(typing_extensions.TypedDict, total=False):
    email: str

@typing.type_check_only
class ListContent(typing_extensions.TypedDict, total=False):
    listItems: _list[ListItem]

@typing.type_check_only
class ListItem(typing_extensions.TypedDict, total=False):
    checked: bool
    childListItems: _list[ListItem]
    text: TextContent

@typing.type_check_only
class ListNotesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    notes: _list[Note]

@typing.type_check_only
class Note(typing_extensions.TypedDict, total=False):
    attachments: _list[Attachment]
    body: Section
    createTime: str
    name: str
    permissions: _list[Permission]
    title: str
    trashTime: str
    trashed: bool
    updateTime: str

@typing.type_check_only
class Permission(typing_extensions.TypedDict, total=False):
    deleted: bool
    email: str
    family: Family
    group: Group
    name: str
    role: typing_extensions.Literal["ROLE_UNSPECIFIED", "OWNER", "WRITER"]
    user: User

@typing.type_check_only
class Section(typing_extensions.TypedDict, total=False):
    list: ListContent
    text: TextContent

@typing.type_check_only
class TextContent(typing_extensions.TypedDict, total=False):
    text: str

@typing.type_check_only
class User(typing_extensions.TypedDict, total=False):
    email: str
